==> tine20-humanresources_2019.12.5.tar.bz2: HumanResources/js/HumanResources-lang-hr_HR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of HumanResources **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nLanguage: hr_HR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "You do not have admin rights on HumanResources"
: "Nemate admin prava na Ljudske resurse."

, "Wage types"
: ""

, "Free time types"
: ""

, "Working time scheme, Working time schemes"
: [
  ""
 ,""
 ,""

]
, "Book as vacation"
: ""

, "Sickness"
: "Bolovanje"

, "Sickness Days"
: ""

, "Vacation"
: "Godišnji odmor"

, "Vacation Days"
: "Godišnji odmor"

, "There could not be found any {0}. Please try to change your filter-criteria or view-options."
: ""

, "Could not book as vacation"
: ""

, "The unexcused sickness days could not be booked as vacation. There are not enough days left!"
: ""

, "Human Resources, Human Resources"
: [
  ""
 ,""
 ,""

]
, "Template"
: ""

, "Individual"
: ""

, "Shared"
: ""

, "Edit {0} for {1} - {2}"
: ""

, "Extra free time, Extra free times"
: [
  ""
 ,""
 ,""

]
, "Summary"
: ""

, "Free Times"
: ""

, "Possible vaction days"
: ""

, "Remaining vaction days"
: ""

, "Taken vaction days"
: ""

, "Expired vaction days"
: ""

, "Rebooked vaction days"
: ""

, "Excused sickness days"
: ""

, "Unexcused sickness days"
: ""

, "Working Time"
: ""

, "Days to work"
: ""

, "Hours to work"
: ""

, "Days to work after vacation and sickness"
: ""

, "Hours to work after vacation and sickness"
: ""

, "Miscellaneous"
: ""

, "Description"
: "Opis"

, "Employee, Employees"
: [
  "Zaposlenik"
 ,"Zaposlenika"
 ,"Zaposlenika"

]
, "Calculate all Reports"
: ""

, "Recalculate"
: ""

, "Cancel"
: "Odustani"

, "OK"
: "Potvrdi"

, "Please use the following format: MM-DD"
: ""

, "Calendar"
: "Kalendar"

, "Calendars"
: "Kalendari"

, "Vacation expires"
: ""

, "Book remaining vacation"
: ""

, "Year"
: ""

, "Please enter the year you want to create accounts for:"
: ""

, "Accounts have been created"
: ""

, "{0} accounts for the year {1} have been created successfully!"
: ""

, "Create new accounts"
: ""

, "Booking has been successfull!"
: ""

, "The remaining vacation days of the selected accounts have been booked successfully!"
: ""

, "CostCenter, CostCenters"
: [
  ""
 ,""
 ,""

]
, "Cost Center, Cost Centers"
: [
  ""
 ,""
 ,""

]
, "Startdate"
: ""

, "Contract, Contracts"
: [
  "Ugovor"
 ,"Ugovora"
 ,"Ugovora"

]
, "Vacation in same period"
: ""

, "There are some vacation days matching the period of the contract you added. After saving this employee, changing the contract is not possible anymore."
: ""

, "Edit {0}"
: ""

, "Working Time Rules"
: ""

, "Start Date"
: "Datum početka"

, "End Date"
: "Datum završetka"

, "Feast Calendar"
: "Neradni dani"

, "Vacation days of one calendar year"
: ""

, "Working Time Schema"
: ""

, "Working Hours per week"
: ""

, "Mon."
: ""

, "Tue."
: ""

, "Wed."
: ""

, "Thu."
: ""

, "Fri."
: ""

, "Sat."
: ""

, "Sun."
: ""

, "Edit {0} \"{1}\""
: ""

, "Edit {0} for {1}"
: ""

, "Add {0} for {1}"
: ""

, "You have to select at least one day to save this sickness entry."
: ""

, "You have to select at least one day to save this vacation entry."
: ""

, "No day selected"
: ""

, "Personal account, Personal accounts"
: [
  ""
 ,""
 ,""

]
, "Status"
: "Status"

, "Remaining"
: ""

, "Select Days"
: "Odaberi dane"

, "Enter description"
: "Unesi opis"

, "Account is disabled or deleted!"
: ""

, "Division"
: "Odjel"

, "Health Insurance"
: "Zdravstveno osiguranje"

, "Apply contact data on form"
: "Postaviti kontakt podatke"

, "Salutation"
: "Oslovljavanje"

, "Personal Information"
: "Osobne informacije"

, "Country"
: "Država"

, "Birthday"
: "Datum rođenja"

, "Internal Information"
: "Interne informacije"

, "Banking Information"
: "Bankarske informacije"

, "Type"
: "Tip"

, "Template (individual working time schemas are created for each contract)"
: ""

, "Shared (this working time schemas can be shared among contracts)"
: ""

, "Days"
: ""

, "Expiration date"
: ""

, "WK"
: "tjedan"

, "Loading calendar data..."
: "Učitavanje kalendara.."

, "Year can not be changed"
: ""

, "You have already selected some dates from another year. Please create a new record to add dates from another year!"
: ""

, "No more vacation days"
: ""

, "The Employee has no more possible vacation days left for this year. Create a new vacation and use another personal account the vacation should be taken from."
: ""

, "Excused"
: ""

, "Unexcused"
: ""

, "Currently employed"
: ""

, "Employees which are currently employed"
: ""

, "All employees"
: ""

, "All available employees"
: ""

, "Payed"
: ""

, "Not payed"
: ""

, "Currently employed employees"
: ""

, "All accounts"
: ""

, "All available accounts"
: ""

, "Full-time 40 hours"
: ""

, "Full-time 37.5 hours"
: ""

, "Part-time 20 hours"
: ""

, "Default wage type"
: ""

, "Salary"
: ""

, "Business trip"
: ""

, "Sunday bonus"
: ""

, "Feast day"
: ""

, "Feast day bonus"
: ""

, "Overtime"
: ""

, "Overtime bonus"
: ""

, "Late shift bonus"
: ""

, "Night bonus"
: ""

, "Break"
: ""

, "Stand by"
: ""

, "Unpaid"
: ""

, "[S] Sickness"
: ""

, "[D] Visit doctor"
: ""

, "[V] Vacation"
: ""

, "[BT] Business trip"
: ""

, "[FT] Flex time"
: ""

, "[BK] Break"
: ""

, "[T] Training"
: ""

, "Freetime Type"
: "Tip slobodnih dana"

, "Possible free time definitions"
: ""

, "Vacation Status"
: ""

, "Possible vacation status definitions"
: ""

, "Requested"
: "Zahtjevi"

, "In process"
: "U tijeku"

, "Accepted"
: "Prihvaćeno"

, "Declined"
: "Odbijeno"

, "Sickness Status"
: ""

, "Possible sickness status definitions"
: ""

, "Default Feast Calendar"
: ""

, "Here you can define the default feast calendar used to set feast days and other free days in datepicker"
: ""

, "Enabled Features"
: ""

, "Enabled Features in HumanResources Application."
: ""

, "Calculate Daily Reports"
: ""

, "Activate to calculate daily reports with a nightly scheduler job"
: ""

, "Extra freetime type"
: ""

, "Possible extra free time definitions"
: ""

, "Here you can define the day, when the vacation days taken from last year expires, the format is MM-DD."
: ""

, "Report Templates Node ID"
: ""

, "Timetracker Timeaccount for Workingtime Tracking"
: ""

, "No valid contract for this date"
: ""

, "unexpected error: "
: ""

, "daily wt reports can't be created"
: ""

, "It is not allowed to update a cleared report"
: ""

, "monthly wt reports can't be created"
: ""

, "previous months need to be cleared first"
: ""

, "following months need to be uncleared first"
: ""

, "Daily Working Time Report, Daily Working Time Reports"
: [
  ""
 ,""
 ,""

]
, "Date"
: ""

, "Evaluation Start Time"
: ""

, "Evaluation End Time"
: ""

, "Corrected Evaluation Start Time"
: ""

, "Corrected Evaluation End Time"
: ""

, "Target Working Time"
: ""

, "Target Working Time Correction"
: ""

, "Break Time Net"
: ""

, "Break Deduction Time"
: ""

, "Working Times"
: ""

, "Actual Working Time"
: ""

, "Working Time Correction"
: ""

, "Total Working Time"
: ""

, "System Remark"
: ""

, "Remark"
: ""

, "Is Cleared"
: ""

, "Calculation Error"
: ""

, "Monthly Working Time Report, Monthly Working Time Reports"
: [
  ""
 ,""
 ,""

]
, "Month"
: ""

, "Daily Working Time Reports"
: ""

, "Working Time Balance Previous Month"
: ""

, "Total Working Time Balance"
: ""

, "Wage type, Wage types"
: [
  ""
 ,""
 ,""

]
, "Abbreviation"
: ""

, "Name"
: ""

, "System"
: ""

, "Factor (%)"
: ""

, "Additional Wage"
: ""

, "Quick search"
: ""

, "Extra free times"
: ""

, "Start time"
: ""

, "Break Time, Break Times"
: [
  ""
 ,""
 ,""

]
, "After exceeding {{time_worked|date(\"H:i\", \"GMT\")}} of working time {{break_time|date(\"H:i\", \"GMT\")}} break time gets deducted automatically."
: ""

, "Time worked"
: ""

, "Break time"
: ""

, "Work Time Limit, Work Time Limits"
: [
  ""
 ,""
 ,""

]
, "Working time is evaluated from {{start_time|date(\"H:i\")}} until {{end_time|date(\"H:i\")}}."
: ""

, "Absence reason, Absence reasons"
: [
  ""
 ,""
 ,""

]
, "Allow Booking"
: ""

, "Allow Planning"
: ""

, "Enable Freetime Timetracking"
: ""

, "Timeaccount"
: ""

, "Free Time, Free Times"
: [
  "Slobodan dan"
 ,"Slobodna dana"
 ,"Slobodnih dana"

]
, "Account"
: "Račun"

, "First Day"
: ""

, "Last Day"
: ""

, "Days Count"
: ""

, "Free Days"
: ""

, "Private Information"
: ""

, "Is employed"
: ""

, "Number"
: "Broj"

, "Transponder Id"
: ""

, "Germany"
: ""

, "Locality"
: "Mjesto"

, "Postalcode"
: "Poštanski broj"

, "Region"
: "Regija"

, "Street"
: "Ulica"

, "Street 2"
: ""

, "E-Mail"
: "Email"

, "Telephone Number"
: "Telefon"

, "Cell Phone Number"
: "Mobitel"

, "Title"
: "Titula"

, "Last Name"
: "Prezime"

, "First Name"
: "Ime"

, "Employee name"
: "Naziv zaposlenika"

, "Account Holder"
: "Vlasnik računa"

, "Account Number"
: "Broj računa"

, "Bank Name"
: "Naziv banke"

, "Code Number"
: "Kod"

, "Employment begin"
: "Datum zaposlenja"

, "Employment end"
: "Prekid radnog odnosa"

, "Supervisor"
: "Nadređeni"

, "Profession"
: "Struka"

, "Position"
: ""

, "Contracts"
: ""

, "Cost Centers"
: ""

, "Free Day, Free Days"
: [
  "Slobodan dan"
 ,"Slobodna dana"
 ,"Slobodnih dana"

]
, "No contract could be found."
: "Nema pronađenih ugovora."

, "Please create a contract for this employee!"
: "Kreirajte ugovor za odabranog zaposlenika."

, "Negative Timespace"
: ""

, "The start date of the contract must be before the end date!"
: ""

, "Not allowed!"
: ""

, "It's only allowed to book remaining vacation days from years in the past!"
: ""

, "Contracts overlap"
: ""

, "The contracts must not overlap!"
: ""

, "No or no valid year given"
: ""

, "Please use a valid year!"
: ""

, "No current contract!"
: ""

, "A current contract could not be found!"
: ""

, "Contract not editable"
: ""

, "You are not allowed to change the record if a vacation has been booked already!"
: ""

, "No personal account found"
: ""

, "An existing personal account could not be found. Please create one!"
: ""

, "edit private employee data"
: "Uredi privatne podatke zaposlenika"

, "Edit birthday, account data and other private information of employee records"
: "Uredi datum rođenja, račun i ostale privatne informacije zaposlenika"

, "Working time scheme"
: ""

, "Human Resources"
: ""

, "Extra free time"
: ""

, "Employee"
: "Zaposlenik"

, "CostCenter"
: ""

, "Cost Center"
: ""

, "Contract"
: "Ugovor"

, "Personal account"
: ""

, "Daily Working Time Report"
: ""

, "Monthly Working Time Report"
: ""

, "Wage type"
: ""

, "Break Time"
: ""

, "Work Time Limit"
: ""

, "Absence reason"
: ""

, "Free Time"
: "Slobodan dan"

, "Free Day"
: "Slobodan dan"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-humanresources_2020.08.8.tar.bz2: HumanResources/js/HumanResources-lang-hr_HR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of HumanResources **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nLanguage: hr_HR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "You do not have admin rights on HumanResources"
: "Nemate admin prava na Ljudske resurse."

, "Working time model"
: ""

, "Book as vacation"
: ""

, "Sickness"
: "Bolovanje"

, "Sickness Days"
: ""

, "Vacation"
: "Godišnji odmor"

, "Vacation Days"
: "Godišnji odmor"

, "There could not be found any {0}. Please try to change your filter-criteria or view-options."
: ""

, "Could not book as vacation"
: ""

, "The unexcused sickness days could not be booked as vacation. There are not enough days left!"
: ""

, "Human Resources, Human Resources"
: [
  ""
 ,""
 ,""

]
, "Title"
: "Titula"

, "Work Start"
: ""

, "Work End"
: ""

, "Edit {0} for {1} - {2}"
: ""

, "Extra free time, Extra free times"
: [
  ""
 ,""
 ,""

]
, "Summary"
: ""

, "Free Times"
: ""

, "Possible vaction days"
: ""

, "Remaining vaction days"
: ""

, "Taken vaction days"
: ""

, "Expired vaction days"
: ""

, "Rebooked vaction days"
: ""

, "Excused sickness days"
: ""

, "Unexcused sickness days"
: ""

, "Working Time"
: ""

, "Days to work"
: ""

, "Hours to work"
: ""

, "Days to work after vacation and sickness"
: ""

, "Hours to work after vacation and sickness"
: ""

, "Miscellaneous"
: ""

, "Description"
: "Opis"

, "Working time Model"
: ""

, "Work start"
: ""

, "not set"
: ""

, "Work end"
: ""

, "Working Hours per week"
: ""

, "Mon."
: ""

, "Tue."
: ""

, "Wed."
: ""

, "Thu."
: ""

, "Fri."
: ""

, "Sat."
: ""

, "Sun."
: ""

, "Employee, Employees"
: [
  "Zaposlenik"
 ,"Zaposlenika"
 ,"Zaposlenika"

]
, "Cancel"
: "Odustani"

, "OK"
: "Potvrdi"

, "Please use the following format: MM-DD"
: ""

, "Calendar"
: "Kalendar"

, "Calendars"
: "Kalendari"

, "Vacation expires"
: ""

, "Breaks"
: ""

, "Hours"
: ""

, "Break duration"
: ""

, "Book remaining vacation"
: ""

, "Year"
: ""

, "Please enter the year you want to create accounts for:"
: ""

, "Accounts have been created"
: ""

, "{0} accounts for the year {1} have been created successfully!"
: ""

, "Create new accounts"
: ""

, "Booking has been successfull!"
: ""

, "The remaining vacation days of the selected accounts have been booked successfully!"
: ""

, "CostCenter, CostCenters"
: [
  ""
 ,""
 ,""

]
, "Cost Center, Cost Centers"
: [
  ""
 ,""
 ,""

]
, "Startdate"
: ""

, "Contract, Contracts"
: [
  "Ugovor"
 ,"Ugovora"
 ,"Ugovora"

]
, "Vacation in same period"
: ""

, "There are some vacation days matching the period of the contract you added. After saving this employee, changing the contract is not possible anymore."
: ""

, "Edit {0}"
: ""

, "Start Date"
: "Datum početka"

, "End Date"
: "Datum završetka"

, "Feast Calendar"
: "Neradni dani"

, "Choose the template"
: ""

, "Vacation days of one calendar year"
: ""

, "Edit {0} \"{1}\""
: ""

, "Edit {0} for {1}"
: ""

, "Add {0} for {1}"
: ""

, "You have to select at least one day to save this sickness entry."
: ""

, "You have to select at least one day to save this vacation entry."
: ""

, "No day selected"
: ""

, "Personal account, Personal accounts"
: [
  ""
 ,""
 ,""

]
, "Status"
: "Status"

, "Remaining"
: ""

, "Select Days"
: "Odaberi dane"

, "Enter description"
: "Unesi opis"

, "Account is disabled or deleted!"
: ""

, "Division"
: "Odjel"

, "Health Insurance"
: "Zdravstveno osiguranje"

, "Apply contact data on form"
: "Postaviti kontakt podatke"

, "Salutation"
: "Oslovljavanje"

, "Personal Information"
: "Osobne informacije"

, "Country"
: "Država"

, "Birthday"
: "Datum rođenja"

, "Internal Information"
: "Interne informacije"

, "Banking Information"
: "Bankarske informacije"

, "Days"
: ""

, "Type"
: "Tip"

, "Expiration date"
: ""

, "WK"
: "tjedan"

, "Loading calendar data..."
: "Učitavanje kalendara.."

, "Year can not be changed"
: ""

, "You have already selected some dates from another year. Please create a new record to add dates from another year!"
: ""

, "No more vacation days"
: ""

, "The Employee has no more possible vacation days left for this year. Create a new vacation and use another personal account the vacation should be taken from."
: ""

, "Excused"
: ""

, "Unexcused"
: ""

, "Currently employed"
: ""

, "Employees which are currently employed"
: ""

, "All employees"
: ""

, "All available employees"
: ""

, "Payed"
: ""

, "Not payed"
: ""

, "Currently employed employees"
: ""

, "All accounts"
: ""

, "All available accounts"
: ""

, "Full-time 40 hours"
: ""

, "Full-time 37.5 hours"
: ""

, "Part-time 20 hours"
: ""

, "Freetime Type"
: "Tip slobodnih dana"

, "Possible free time definitions"
: ""

, "Vacation Status"
: ""

, "Possible vacation status definitions"
: ""

, "Requested"
: "Zahtjevi"

, "In process"
: "U tijeku"

, "Accepted"
: "Prihvaćeno"

, "Declined"
: "Odbijeno"

, "Sickness Status"
: ""

, "Possible sickness status definitions"
: ""

, "Default Feast Calendar"
: ""

, "Here you can define the default feast calendar used to set feast days and other free days in datepicker"
: ""

, "Enabled Features"
: ""

, "Enabled Features in HumanResources Application."
: ""

, "Calculate Daily Reports"
: ""

, "Activate to calculate daily reports with a nightly scheduler job"
: ""

, "Extra freetime type"
: ""

, "Possible extra free time definitions"
: ""

, "Here you can define the day, when the vacation days taken from last year expires, the format is MM-DD."
: ""

, "Report Templates Node ID"
: ""

, "Timetracker Timeaccount for Workingtime Tracking"
: ""

, "Daily Working Time Report, Daily Working Time Reports"
: [
  ""
 ,""
 ,""

]
, "Date"
: ""

, "Evaluation Start Time"
: ""

, "Evaluation End Time"
: ""

, "Paid Absence Time"
: ""

, "Unpaid Absence Time"
: ""

, "Absence"
: ""

, "Break Time Net"
: ""

, "Break Deduction Time"
: ""

, "Feast Time"
: ""

, "Break Time"
: ""

, "Sickness Time"
: ""

, "Working Time Correction"
: ""

, "Actual Working Time"
: ""

, "Target Working Time"
: ""

, "System Remark"
: ""

, "Remark"
: ""

, "Is Cleared"
: ""

, "Cleared in"
: ""

, "Working time, Working times"
: [
  ""
 ,""
 ,""

]
, "Quick search"
: ""

, "Extra free times"
: ""

, "Free Time, Free Times"
: [
  "Slobodan dan"
 ,"Slobodna dana"
 ,"Slobodnih dana"

]
, "Account"
: "Račun"

, "First Day"
: ""

, "Last Day"
: ""

, "Days Count"
: ""

, "Free Days"
: ""

, "Private Information"
: ""

, "Is employed"
: ""

, "Number"
: "Broj"

, "Badge Id"
: ""

, "Germany"
: ""

, "Locality"
: "Mjesto"

, "Postalcode"
: "Poštanski broj"

, "Region"
: "Regija"

, "Street"
: "Ulica"

, "Street 2"
: ""

, "E-Mail"
: "Email"

, "Telephone Number"
: "Telefon"

, "Cell Phone Number"
: "Mobitel"

, "Last Name"
: "Prezime"

, "First Name"
: "Ime"

, "Employee name"
: "Naziv zaposlenika"

, "Account Holder"
: "Vlasnik računa"

, "Account Number"
: "Broj računa"

, "Bank Name"
: "Naziv banke"

, "Code Number"
: "Kod"

, "Employment begin"
: "Datum zaposlenja"

, "Employment end"
: "Prekid radnog odnosa"

, "Supervisor"
: "Nadređeni"

, "Profession"
: "Struka"

, "Position"
: ""

, "Contracts"
: ""

, "Cost Centers"
: ""

, "Free Day, Free Days"
: [
  "Slobodan dan"
 ,"Slobodna dana"
 ,"Slobodnih dana"

]
, "Break, Breaks"
: [
  ""
 ,""
 ,""

]
, "Workingtime"
: ""

, "No contract could be found."
: "Nema pronađenih ugovora."

, "Please create a contract for this employee!"
: "Kreirajte ugovor za odabranog zaposlenika."

, "Negative Timespace"
: ""

, "The start date of the contract must be before the end date!"
: ""

, "Not allowed!"
: ""

, "It's only allowed to book remaining vacation days from years in the past!"
: ""

, "Contracts overlap"
: ""

, "The contracts must not overlap!"
: ""

, "No or no valid year given"
: ""

, "Please use a valid year!"
: ""

, "No current contract!"
: ""

, "A current contract could not be found!"
: ""

, "Contract not editable"
: ""

, "You are not allowed to change the record if a vacation has been booked already!"
: ""

, "No personal account found"
: ""

, "An existing personal account could not be found. Please create one!"
: ""

, "edit private employee data"
: "Uredi privatne podatke zaposlenika"

, "Edit birthday, account data and other private information of employee records"
: "Uredi datum rođenja, račun i ostale privatne informacije zaposlenika"

, "Public Holiday Calendar"
: ""

, "Here you can define the default public holiday calendar used to set public holidays and other free days in datepicker"
: ""

, "Public Holidays"
: ""

, "Badge ID"
: ""

, "Human Resources"
: ""

, "Extra free time"
: ""

, "Employee"
: "Zaposlenik"

, "CostCenter"
: ""

, "Cost Center"
: ""

, "Contract"
: "Ugovor"

, "Personal account"
: ""

, "Daily Working Time Report"
: ""

, "Working time"
: ""

, "Free Time"
: "Slobodan dan"

, "Free Day"
: "Slobodan dan"

, "Break"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
